import { VisibleOnboardingItem } from './visible-onboarding-item.model';
/**
 * Container to pass visible onboarding elements from onboarding service
 * to onboarding component (which can be grouped by their "group" field).
 *
 * Current group of elements can be accessed via currentItems(). Next group can be accessed via nextItems().
 *
 * Container does not have immediate access to grouping keys since elements are stored in jagged array.
 */
export declare class OnboardingItemContainer {
    private items;
    private totalCount;
    private currentGroupIndex;
    get isEmpty(): boolean;
    /**
     * Check if there is another group of visible onboarding items
     */
    get hasNext(): boolean;
    /**
     * Return current group of visible onboarding items
     */
    get currentItem(): VisibleOnboardingItem;
    /**
     * Return list of All visible onboarding items (regardless of grouping)
     */
    get allItems(): Array<VisibleOnboardingItem>;
    /**
     * Return count of all items (regardless of grouping)
     */
    get totalLength(): number;
    /**
     * Return next group of visible onboarding items
     */
    nextItem(): VisibleOnboardingItem;
    /**
     * Add new group of items
     */
    add(items: Array<VisibleOnboardingItem>): void;
    /**
     * Clear items from container
     */
    clear(): void;
}
