import { DomSanitizer, SafeStyle } from '@angular/platform-browser';
import { VisibleOnboardingItem } from './models/visible-onboarding-item.model';
import { OnboardingService } from './services/onboarding.service';
import { OnboardingItem } from './models/onboarding-item.model';
import { AfterViewInit, OnDestroy, OnInit } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Main component of the onboarding module.
 * Handles the visualization of the onboarding items
 */
export declare class OnboardingComponent implements OnInit, AfterViewInit, OnDestroy {
    onboardingService: OnboardingService;
    private domSanitizer;
    /**
     * current visible onboarding item
     */
    visibleItem: VisibleOnboardingItem;
    /**
     * if true, the "show next" button is visible
     * it false, the "got it" button is visible
     * is true, if there are more items to show
     */
    hasNext: boolean;
    /**
     * Do not assign directly use onboardingSevice.configure
     * Name of the material icon to use (defaults to contact_support) (excludes fontSet,fontIcon and svgIcon)
     **/
    matIconName: string;
    /**
     * Do not assign directly use onboardingSevice.configure
     * icon class for span (bootstrap style) (excludes matIconeName and svgIcon)
     */
    fontSet: string;
    /**
     * Do not assign directly use onboardingSevice.configure
     *  icon class for span (bootstrap style) (excludes matIconeName and svgIcon)
     */
    fontIcon: string;
    /**
     * Do not assign directly use onboardingSevice.configure
     *  name of registered svg icon (excludes matIconeName,fontSet and fontIcon)
     */
    svgIcon: string;
    dynamicCss: SafeStyle;
    private textConfig;
    private buttonConfig;
    private visibleItemsChangedSubscription;
    constructor(onboardingService: OnboardingService, domSanitizer: DomSanitizer);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * gets the fixed position of the html element
     * used by template to set the position of the spotlight
     */
    getPositionStyle(ele: HTMLElement): any;
    isSpotlightTransparent(item: OnboardingItem): boolean;
    /**
     * used by turn off button in template
     */
    disable(): void;
    /**
     * hide current group (show next one if one is available
     */
    hide(): void;
    buttonsPositionStyle(): any;
    /**
     * Show onboarding item
     */
    private showItem;
    /**
     * Hide SINGLE element without change notification
     */
    private hideItem;
    static ɵfac: i0.ɵɵFactoryDeclaration<OnboardingComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<OnboardingComponent, "rosen-onboarding", never, {}, {}, never, never, false, never>;
}
